import { Connections, IConnectable, IInterfaceVpcEndpoint, ISecurityGroup, IVpc, SelectedSubnets } from 'aws-cdk-lib/aws-ec2';
import { CfnConnection } from 'aws-cdk-lib/aws-glue';
import { CfnWorkgroup } from 'aws-cdk-lib/aws-redshiftserverless';
import { Construct } from 'constructs';
import { RedshiftServerlessNamespace } from './redshift-serverless-namespace';
import { RedshiftServerlessWorkgroupProps } from './redshift-serverless-workgroup-props';
import { DataCatalogDatabase } from '../../../../governance';
import { TrackedConstruct } from '../../../../utils';
import { RedshiftDataSharingCreateDbFromShareProps } from '../redshift/data-sharing/redshift-data-sharing-createdbfromshare-props';
import { RedshiftDataSharingGrantedProps } from '../redshift/data-sharing/redshift-data-sharing-granted-props';
import { RedshiftNewShareProps } from '../redshift/data-sharing/redshift-new-share-props';
import { RedshiftData } from '../redshift/redshift-data';
/**
 * Create a Redshift Serverless Workgroup. A default namespace would be created if none is provided.
 *
 * @example
 * const workgroup = new dsf.consumption.RedshiftServerlessWorkgroup(this, "RedshiftWorkgroup", {
 *    name: "example-workgroup",
 *    namespace: new dsf.consumption.RedshiftServerlessNamespace(this, "RedshiftNamespace", {
 *      name: 'example-namespace',
 *      dbName: 'defaultdb',
 *    })
 * });
 */
export declare class RedshiftServerlessWorkgroup extends TrackedConstruct implements IConnectable {
    private static readonly DEFAULT_VPC_CIDR;
    private static readonly DEFAULT_VPC_PRIVATE_SUBNET_NAME;
    private static readonly DEFAULT_PORT;
    /**
     * The created Redshift Serverless Workgroup
     */
    readonly cfnResource: CfnWorkgroup;
    /**
     * Connections used by Workgroup security group. Used this to enable access from clients connecting to the workgroup
     */
    readonly connections: Connections;
    /**
     * The associated Redshift Serverless Namespace
     */
    readonly namespace: RedshiftServerlessNamespace;
    /**
     * The Glue Connection associated with the workgroup. This can be used by Glue ETL Jobs to read/write data from/to Redshift workgroup
     */
    readonly glueConnection: CfnConnection;
    /**
     * The primary EC2 Security Group associated with the Redshift Serverless Workgroup
     */
    readonly primarySecurityGroup: ISecurityGroup;
    /**
     * The VPC where the Redshift Serverless Workgroup is deployed
     */
    readonly vpc: IVpc;
    /**
     * The subnets where the Redshift Serverless Workgroup is deployed
     */
    readonly selectedSubnets: SelectedSubnets;
    /**
     * Index of existing shares
     */
    readonly existingShares: {
        [key: string]: RedshiftNewShareProps;
    };
    private readonly removalPolicy;
    private redshiftData?;
    private redshiftDataSharing?;
    private port;
    constructor(scope: Construct, id: string, props: RedshiftServerlessWorkgroupProps);
    /**
     * Creates a new Glue data catalog database with a crawler using JDBC target type to connect to the Redshift Workgroup
     * @param id The CDK ID of the resource
     * @param catalogDbName The name of the Glue Database to create
     * @param pathToCrawl The path of Redshift tables to crawl @default `<databaseName>/public/%``
     * @returns The DataCatalogDatabase created
     */
    catalogTables(id: string, catalogDbName: string, pathToCrawl?: string): DataCatalogDatabase;
    /**
     * Create a new datashare
     * @param id The CDK ID of the resource
     * @param databaseName The name of the database to connect to
     * @param dataShareName The name of the datashare
     * @param schema The schema to add in the datashare
     * @param tables The list of tables that would be included in the datashare. This must follow the format: `<schema>.<tableName>`
     * @returns `RedshiftNewShareProps`
     */
    createShare(id: string, databaseName: string, dataShareName: string, schema: string, tables: string[]): RedshiftNewShareProps;
    /**
     * Create a datashare grant to a namespace if it's in the same account, or to another account
     * @param id The CDK ID of the resource
     * @param dataShareDetails The details of the datashare
     * @param consumerNamespaceId The namespace of the consumer that you're sharing to. Either namespace or account Id must be provided.
     * @param consumerAccountId The account ID of the consumer that you're sharing to. Either namespace or account Id must be provided.
     * @param autoAuthorized @default false, when this is set to true, cross-account shares would automatically be authorized
     * @returns `RedshiftDataSharingGrantedProps`
     */
    grantAccessToShare(id: string, dataShareDetails: RedshiftNewShareProps, consumerNamespaceId?: string, consumerAccountId?: string, autoAuthorized?: boolean): RedshiftDataSharingGrantedProps;
    /**
     * Consume datashare by creating a new database pointing to the share.
     * If datashare is coming from a different account, setting `autoAssociate` to true
     * automatically associates the datashare to the cluster before the new database is created.
     * @param id The CDK ID of the resource
     * @param newDatabaseName The name of the database that would be created from the data share
     * @param producerDataShareName The name of the data share from producer
     * @param producerNamespaceId The producer cluster namespace
     * @param producerAccountId The producer account ID. Required for cross account shares.
     * @returns `CustomResource`
     */
    createDatabaseFromShare(id: string, newDatabaseName: string, producerDataShareName: string, producerNamespaceId?: string, producerAccountId?: string): RedshiftDataSharingCreateDbFromShareProps;
    /**
     * Create Glue Connection and modifies the Redshift Serverless Workgroup's security group to allow Glue access via self-referencing rule.
     * @param props The properties of the Redshift Serverless Workgroup
     * @returns The Glue Connection to the Redshift Serverless Workgroup
     */
    private createConnection;
    /**
     * Creates an instance of `RedshiftData` to send custom SQLs to the workgroup
     * @param id The CDK ID of the resource
     * @param createVpcEndpoint if set to true, create interface VPC endpoint for Redshift Data API
     * @param existingInterfaceVPCEndpoint if `createVpcEndpoint` is false, and if this is populated,
     * then the Lambda function's security group would be added in the existing VPC endpoint's security group.
     * @returns `RedshiftData`
     */
    accessData(id: string, createVpcEndpoint?: boolean, existingInterfaceVPCEndpoint?: IInterfaceVpcEndpoint): RedshiftData;
    /**
     * Creates an instance of `RedshiftDataSharing` to manage the workgroup's data sharing.
     * @param id The CDK ID of the resource
     * @param createVpcEndpoint if set to true, create interface VPC endpoint for Redshift Data API
     * @param existingInterfaceVPCEndpoint if `createVpcEndpoint` is false, and if this is populated,
     * then the Lambda function's security group would be added in the existing VPC endpoint's security group.
     * @returns `RedshiftDataSharing`
     */
    private dataSharing;
    /**
     * Initialize Security Groups.
     * Convert `SecurityGroup[]` into array of security group ids.
     * Also create a primary security group that clients can use to add ingress rules.
     * @param extraSecurityGroups The list of extra security groups
     * @returns `SecurityGroupDetails`
     */
    private initSecurityGroup;
    private initDefaultNetworking;
}
